function res = metaplot(probname)
% Plots the batch-average of each quantity for all 3 problems, superimposed.
% In each directory there is a text file xx.mid, containing the results
% returned by the plotting functions.
%
% Note: we don't bother with op. probs - too  complicated.

quantityNames = str2mat('BOG fitness',...
    'BOG validation error',...
    'average fitness',...
    'std. deviation of fitness',...
    'average number of features',...
    str2mat('average number of nodes',...
    'average number of introns',...
    'average number of RAT trials',...
    'average optimisation improvement'));

shortQuantNames = str2mat('bogF',...
    'bogV',...
    'aveF',...
    'stdF',...
    'nFtr',...
    str2mat('nNode',...
    'nInt',...
    'nTrl',...
    'optImp'));

% this file assumes that there are 3 directories associated with the
% problem.
np = 3;
linetypes=str2mat('g-','b--','r-.');
for i=1:np,
  dname = [probname,'_',num2str(i)];

  if i==1,
    nameM=dname;
  else
    nameM=str2mat(nameM,dname);
  end;
  
  eval(['cd ',dname,';']);
  
  eval(['results',num2str(i),' = readmid(''',probname,'_',...
	  num2str(i),'.mid'');']);
  
  % we will be left with resultsxx, holding the average results for the
  % quantities.  Store 'em up and print them after
  
  cd ..;
end;

% now plot the combined results
%close all;
for i=1:np,
  eval(['results = results',num2str(i),';']);
  % assume all quantities are present
  for q=1:size(quantityNames,1),
    figure(q);
    plot([0:(size(results,2)-1)],results(q,:), deblank(linetypes(i,:)));
    hold on;
  end; 					%for q
end; 					%for i

% now some cosmetics and printing
for q=1:size(quantityNames,1),
  figure(q);
%  title([probname,': ',deblank(quantityNames(q,:)),' averaged over all runs'],'fontsize',18);
  title([probname,': ',deblank(quantityNames(q,:))],'fontsize',18);
  xlabel('g');
  ylabel(deblank(shortQuantNames(q,:)));
  legend(nameM);
  hold off;
  eval(['print -depsc ',probname,'_',deblank(shortQuantNames(q,:)),'.eps;']);
end; 					%for q

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% now we do a separate plot of the ave op probs for FIRST PERMUTATION
% ONLY
%% these are indexed by the id's which come after the flags(if ops are present)
%$$$ allOpNames = str2mat('High-Level Crossover',...
%$$$ 'Grow Mutation',...
%$$$ 'One-Node Mutation',...
%$$$ 'All-Nodes Mutation',...
%$$$ 'One-Symbol Mutation',...
%$$$ 'Swap Mutation',...
%$$$ 'Truncate Mutation',...
%$$$ 'Hoist Mutation',...
%$$$ 'Add-Feature Mutation',...
%$$$ 'Delete-Feature Mutation',...
%$$$ 'Semantic Mutation');
%$$$ 
%$$$ colourStrings = str2mat('r','g','b','m','c','r--','g--','b--','m--','c--','k');
%$$$ 
%$$$ i=1;	  
%$$$ q=size(quantityNames,1)+1;
%$$$ eval(['results = results',num2str(i),';']);
%$$$ figure(q);
%$$$ 
%$$$ for j=1:flags(10),
%$$$     % for each operator present, plot it
%$$$     plot([0:(size(results,2)-1)],results(q+j-1,:), deblank(colourStrings(j,:)));
%$$$ 	hold on;
%$$$ 	if j==1,
%$$$ 	  opStrings = str2mat(deblank(allOpNames(opIDs(j)+1,:)));
%$$$ 	else
%$$$ 	  opStrings = str2mat(opStrings, deblank(allOpNames(opIDs(j)+1,:))); 
%$$$ 	end;%if
%$$$       end;%for
%$$$       legend(opStrings, -1);
%$$$ 
%$$$ %  title([probname,': ',deblank(quantityNames(q,:)),' averaged over all runs'],'fontsize',18);
%$$$   title([probname,'_1: average operator probabilities'],'fontsize',18);
%$$$   xlabel('g');
%$$$   ylabel('operator probability);
%$$$   eval(['print -depsc ',probname,'_'opProb'.eps;']);
%$$$ end; 					%for q
%$$$ 
%$$$ 
%$$$ 
