function res = plotAndPrint(flags, opIDs, data, name, runNumber, printFlag)
%% res = plotAndPrint(flags, opIDs, data, name, runNumber, printFlag)
%% 
%% Function to plot results from EPrep ver. 3.0 data files.
%% Flags, opIDs and data are obtained from the resultsOfRun function.
%% 'name' is the name of the batch or runs, and 'runNumber' is
%% the run from which these results came.  If it is 0, the
%% results are averaged over all the runs.  Both appear in the
%% title for each plot.  The print flag specifies whether or
%% not to print the results to disk.
%% The plots are saved as colour eps and gif files with names
%% 'name_quantity_runNumber.[eps,gif].

%% these are indexed by the id's which come after the flags(if ops are present)
%$$$ allOpNames = str2mat('High-Level Crossover',...
%$$$ 'Grow Mutation',...
%$$$ 'One-Node Mutation',...
%$$$ 'All-Nodes Mutation',...
%$$$ 'One-Symbol Mutation',...
%$$$ 'Swap Mutation',...
%$$$ 'Truncate Mutation',...
%$$$ 'Hoist Mutation',...
%$$$ 'Add-Feature Mutation',...
%$$$ 'Delete-Feature Mutation',...
%$$$ 'Semantic Mutation');
allOpNames = str2mat('HL Crossover',...
'Grow Mut''n',...
'1-Node Mut''n',...
'All-Nodes Mut''n',...
'1-Symbol Mut''n',...
'Swap Mut''n',...
'Truncate Mut''n',...
'Hoist Mut''n',...
'Add-Ftr. Mut''n',...
'Del.-Ftr. Mut''n',...
'Semantic Mut''n');

colourStrings = str2mat('r','g','b','m','c','r--','g--','b--','m--','c--','k');

quantityNames = str2mat('BOG fitness',...
    'BOG validation error',...
    'ave. fitness',...
    'std. deviation of fitness',...
    'ave. number of features',...
    str2mat('ave. number of nodes',...
    'ave. number of introns',...
    'ave. number of RAT trials',...
    'ave. optimisation improvement',...
    'ave. operator probs.'));

shortQuantNames = str2mat('bogF',...
    'bogV',...
    'aveF',...
    'stdF',...
    'nFtr',...
    str2mat('nNode',...
    'nInt',...
    'nTrl',...
    'optImp',...
    'opProb'));

N = length(flags);
g = size(data,2);
v = version; % matlab 5 supports ppm and not gif, matlab 4 is vice versa

q = 1;

for i=1:N,
  % for each quantity, plot if present
  if flags(i) 
    % open a new figure
    figure(q); 
    clf;
    if (printFlag)
      % if we are printing, it has to have a white background
      whitebg('w');
    else
      whitebg('k');
    end; 				%if
    
    % plot these results (don't forget: generations start at 0)
    plot([0:g-1], data(q,:));
    % add title
    if (runNumber == 0)
      sourceString = ' averaged over all runs.';
    else
      sourceString = [' for run ', num2str(runNumber), '.'];
    end;
%$$$     title ([name, ': plot of ', deblank(quantityNames(i,:)), ...
%$$$ 	    ' versus generation', sourceString]);
    title ([name, ': ', deblank(quantityNames(i,:)), ...
	    sourceString],'fontsize',18);
    xlabel('g');
    ylabel(deblank(shortQuantNames(i,:)));

    if i==10,
      % this is the operator probabilities, which has multiple values.
      % Plot them all and present a legend.
      clf; % start again
      for j=1:flags(10),
	% for each operator present, plot it
	plot([0:g-1], data(j+q-1,:), deblank(colourStrings(j,:)));
	hold on;
	if j==1,
	  opStrings = str2mat(deblank(allOpNames(opIDs(j)+1,:)));
	else
	  opStrings = str2mat(opStrings, deblank(allOpNames(opIDs(j)+1,:))); 
	end;%if
      end;%for
      % have to do this stuff again
      % add title
      if (runNumber == 0)
	sourceString = ' averaged over all runs.';
      else
	sourceString = [' for run ', num2str(runNumber), '.'];
      end;
      title ([name, ': ', deblank(quantityNames(i,:)), ...
	      sourceString],'fontsize',18);
%$$$       title ([name, ': plot of ', deblank(quantityNames(i,:)), ...
%$$$ 	      ' versus generation', sourceString]);
      xlabel('g');
      ylabel(deblank(shortQuantNames(i,:)));
      legend(opStrings, -1);
      hold off;
    end;%if
    
    if (printFlag)
      % print this plot to eps and gif file.
      if runNumber == 0,
	rnstring = 'ave';
      else
	rnstring = num2str(runNumber);
      end;%if
      printfn = [name, '_', deblank(shortQuantNames(i,:)), '_', ...
	      rnstring, '.eps'];
      eval (['print -depsc ', printfn, ';']);
      if (v(1) == '4')
	% version 4 of matlab - output a gif
	printfn = [name, '_', deblank(shortQuantNames(i,:)), '_', ...
		rnstring, '.gif'];
	eval (['print -dgif8 ', printfn, ';']);
      else
	% version 5 - output a ppm
	printfn = [name, '_', deblank(shortQuantNames(i,:)), '_', ...
		rnstring, '.ppm'];
	eval (['print -dppm ', printfn, ';']);
      end;%if
    end;%if
    
    % increment quantity counter
    q = q+1;
  end; %if
end; %for
