function [flags, opIDs, res, g] = resultsOfRun(filename)
%% [flags, opIDs, res, g] = resultsOfRun(filename)
%% 
%% Used with EPrep ver. 3.0 to read in the data for one run.
%% Returns:
%%   flags: boolean flags specifying whether each of the following quantities
%%          has been recorded:
%%            flags(1) : RAT training error
%%            flags(2) : validation error
%%            flags(3) : ave fitness
%%            flags(4) : std dev of fitness
%%            flags(5) : n features
%%            flags(6) : n nodes
%%            flags(7) : n introns
%%            flags(8) : n trials
%%            flags(9) : optimisation improvement
%%            flags(10) : number of operator probabilities
%%   opIDs: for each genetic operator present, it's id is specified in this
%%          vector of length flags(10).
%%   res:   an Nxg matrix, where N is sum(flags) and g is the number of 
%%          generations for the run, which contains each result in the above
%%          order in each row.
%%   g:     number of generations for this run.


%% open file
f = fopen(filename);
if (f == -1)
  disp(['resultsOfRun.m: Error opening data file ', filename]);
  return;
end;

%% read in flags
flags = fread(f, 10, 'char');
N = sum(flags);

%% and operator id's
opIDs = fread(f, flags(10), 'char');

g = 0;
res = [];

%% while not at end of file (this is how we count generations), read
%% in the results for each generation (ie: each column of results matrix).
while ~feof(f),
  %% all the data are reals, so just read them in
  tmp = fread(f, N, 'float');
  if (min(size(tmp)))
%  if (length(tmp) == N)
    res = [res,tmp];
    g = g+1;
  end;%if
end;% while

%% close file
fclose(f);